import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

public class MiniAgenda
   extends JFrame implements ActionListener, ItemListener
{
   private static final String
      TITRE_DFAUT = "Mini agenda du cours de Java";

   //
   // --- Attributs et mthodes associs aux mois
   //
   public static final int
      JAN = 0, FV =  1, MAR =  2,
      AVR = 3, MAI =  4, JUN =  5,
      JUL = 6, AO =  7, SEP =  8,
      OCT = 9, NOV = 10, DEC = 11,
      NB_MOIS = 12;

   //
   // Note: Java supporte ce genre de raccourci
   // pour l'initialisation de tableaux, et en
   // particulier dans le cas de String
   //
   public static final String [] NOMS_MOIS =
   {
      "Janvier", "Fvrier",  "Mars",
      "Avril",   "Mai",      "Juin",
      "Juillet", "Aot",     "Septembre",
      "Octobre", "Novembre", "Dcembre"
   };

   private int m_MoisCourant;

   private JLabel m_NomMoisCourant;
   private JTextArea m_CeMoisCi;
   private JLabel m_tatApplication;
   private JButton m_BoutonMoisProchain,
                   m_BoutonMoisPrcdent;
   private JComboBox m_ChoisirMois;


   public static boolean MoisEstValide (final int Mois)
   {
      return Mois >= JAN && Mois <= DEC;
   }
   private void SetMoisCourantBrut (final int MoisCourant)
   {
      m_MoisCourant = MoisCourant;
   }
   public void SetMoisCourant (final int MoisCourant)
      throws Exception
   {
      if (!MoisEstValide (MoisCourant))
         throw new Exception ("Mois hors bornes " + MoisCourant);
      SetMoisCourantBrut (MoisCourant);
   }
   public int GetMoisCourant ()
   {
      return m_MoisCourant;
   }

   //
   // Navigation d'un mois  l'autre
   //
   public void MoisProchain ()
   {
      SetMoisCourantBrut ((GetMoisCourant () + 1) % NB_MOIS);
   }
   public void MoisPrcdent ()
   {
      if (GetMoisCourant () == JAN)
         SetMoisCourantBrut (DEC);
      else
         SetMoisCourantBrut (GetMoisCourant () - 1);
   }


   //
   // Consructeurs
   //
   public MiniAgenda ()
   {
      this (TITRE_DFAUT);
   }

   public MiniAgenda (final String Titre)
   {
      super (Titre);
      SetMoisCourantBrut (JAN);
   }


   public void init ()
   {
      //
      // PanneauContrle
      //
      JPanel PanneauContrle = new JPanel ();
      m_ChoisirMois = new JComboBox (NOMS_MOIS);
      m_BoutonMoisProchain = new JButton ("Mois prochain  -->");
      m_BoutonMoisPrcdent= new JButton ("<-- Mois prcdent");

      m_BoutonMoisProchain.addActionListener (this);
      m_BoutonMoisPrcdent.addActionListener (this);
      m_ChoisirMois.addItemListener     (this);

      PanneauContrle.setLayout (new GridLayout (6, 1));
      Box b = Box.createHorizontalBox ();
      b.add (m_BoutonMoisPrcdent);
      b.add (m_BoutonMoisProchain);

      // Quatre ranges vides
      PanneauContrle.add (new JLabel (""));
      PanneauContrle.add (new JLabel (""));
      PanneauContrle.add (new JLabel (""));
      PanneauContrle.add (new JLabel (""));
      PanneauContrle.add (b);
      PanneauContrle.add (m_ChoisirMois);

      //
      // PanneauDonnes
      //
      JPanel PanneauDonnes = new JPanel ();
      final int LARGEUR_CE_MOIS_CI = 20,
                HAUTEUR_CE_MOIS_CI = 10;

      PanneauDonnes.setLayout (new BorderLayout ());

      m_CeMoisCi = new JTextArea ("", HAUTEUR_CE_MOIS_CI,
                                      LARGEUR_CE_MOIS_CI);
      m_NomMoisCourant = new JLabel ("");
      PanneauDonnes.add (m_NomMoisCourant, BorderLayout.NORTH);
      PanneauDonnes.add (m_CeMoisCi, BorderLayout.CENTER);

      //
      // Panneautat
      //
      JPanel Panneautat = new JPanel ();

      Panneautat.setLayout (new FlowLayout ());
      m_tatApplication = new JLabel ("Veuillez choisir un mois");
      Panneautat.add (m_tatApplication);

      getContentPane ().add (PanneauContrle, BorderLayout.WEST);
      getContentPane ().add (PanneauDonnes,  BorderLayout.EAST);
      getContentPane ().add (Panneautat,     BorderLayout.SOUTH);

      RafrachirAffichage ();
   }

   private void RafrachirAffichage ()
   {
      m_NomMoisCourant.setText (" faire pendant le mois de " +
                                NOMS_MOIS[GetMoisCourant ()]);
      if (GetMoisCourant () != m_ChoisirMois.getSelectedIndex ())
         m_ChoisirMois.setSelectedIndex (GetMoisCourant  ());
      pack ();
   }


   public void actionPerformed (ActionEvent e)
   {
      if (e.getSource () == m_BoutonMoisProchain)
         MoisProchain ();
      else if (e.getSource () == m_BoutonMoisPrcdent)
         MoisPrcdent ();

      RafrachirAffichage ();
   }

   public void itemStateChanged (ItemEvent e)
   {
      SetMoisCourantBrut (m_ChoisirMois.getSelectedIndex ());
      RafrachirAffichage ();
   }

   public static void main (String [] args)
   {
      MiniAgenda ma = new MiniAgenda ();
      ma.init ();
      ma.pack ();
      ma.addWindowListener
      (
         new WindowAdapter()
         {
            public void windowClosing (WindowEvent e)
            {
               System.exit (0);
            }
         }
      );
      ma.show ();
   }
}
